@@ -5,7 +5,7 @@
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    https://www.imagemagick.org/script/license.php
+    https://imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -47,9 +47,6 @@ extern "C" {
 #  undef inline
 # endif
 #endif
-#if __cplusplus > 199711L
-#define register
-#endif
 
 #define MAGICKCORE_CHECK_VERSION(major,minor,micro) \
   ((MAGICKCORE_MAJOR_VERSION > (major)) || \
