@@ -5,7 +5,7 @@
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    https://www.imagemagick.org/script/license.php
+    https://imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -23,28 +23,7 @@ extern "C" {
 #endif
 
 typedef struct _MagicInfo
-{
-  char
-    *path,
-    *name,
-    *target;
-
-  unsigned char
-    *magic;
-
-  size_t
-    length;
-
-  MagickOffsetType
-    offset;
-
-  MagickBooleanType
-    exempt,
-    stealth;
-
-  size_t
-    signature;
-} MagicInfo;
+  MagicInfo;
 
 extern MagickExport char
   **GetMagicList(const char *,size_t *,ExceptionInfo *);
