@@ -5,7 +5,7 @@
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    https://www.imagemagick.org/script/license.php
+    https://imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -394,6 +394,7 @@ extern "C" {
 #define GetImageAlphaChannel  PrependMagickMethod(GetImageAlphaChannel)
 #define GetImageArtifact  PrependMagickMethod(GetImageArtifact)
 #define GetImageBoundingBox  PrependMagickMethod(GetImageBoundingBox)
+#define GetImageColorspaceType  PrependMagickMethod(GetImageColorspaceType)
 #define GetImageDecoder  PrependMagickMethod(GetImageDecoder)
 #define GetImageDepth  PrependMagickMethod(GetImageDepth)
 #define GetImageDistortion  PrependMagickMethod(GetImageDistortion)
@@ -558,7 +559,7 @@ extern "C" {
 #define GetVirtualMetacontentFromNexus  PrependMagickMethod(GetVirtualMetacontentFromNexus)
 #define GetVirtualMetacontent  PrependMagickMethod(GetVirtualMetacontent)
 #define GetVirtualPixelQueue  PrependMagickMethod(GetVirtualPixelQueue)
-#define GetVirtualPixelsFromNexus  PrependMagickMethod(GetVirtualPixelsFromNexus)
+#define GetVirtualPixelCacheNexus  PrependMagickMethod(GetVirtualPixelCacheNexus)
 #define GetVirtualPixelsNexus  PrependMagickMethod(GetVirtualPixelsNexus)
 #define GetVirtualPixels  PrependMagickMethod(GetVirtualPixels)
 #define GetXMLTreeAttribute  PrependMagickMethod(GetXMLTreeAttribute)
@@ -790,129 +791,6 @@ extern "C" {
 #define ReferenceBlob  PrependMagickMethod(ReferenceBlob)
 #define ReferenceImage  PrependMagickMethod(ReferenceImage)
 #define ReferencePixelCache  PrependMagickMethod(ReferencePixelCache)
-#define RegisterAAIImage  PrependMagickMethod(RegisterAAIImage)
-#define RegisterARTImage  PrependMagickMethod(RegisterARTImage)
-#define RegisterAVSImage  PrependMagickMethod(RegisterAVSImage)
-#define RegisterBGRImage  PrependMagickMethod(RegisterBGRImage)
-#define RegisterBMPImage  PrependMagickMethod(RegisterBMPImage)
-#define RegisterBRAILLEImage  PrependMagickMethod(RegisterBRAILLEImage)
-#define RegisterCALSImage  PrependMagickMethod(RegisterCALSImage)
-#define RegisterCAPTIONImage  PrependMagickMethod(RegisterCAPTIONImage)
-#define RegisterCINImage  PrependMagickMethod(RegisterCINImage)
-#define RegisterCIPImage  PrependMagickMethod(RegisterCIPImage)
-#define RegisterCLIPImage  PrependMagickMethod(RegisterCLIPImage)
-#define RegisterCMYKImage  PrependMagickMethod(RegisterCMYKImage)
-#define RegisterCUTImage  PrependMagickMethod(RegisterCUTImage)
-#define RegisterDCMImage  PrependMagickMethod(RegisterDCMImage)
-#define RegisterDDSImage  PrependMagickMethod(RegisterDDSImage)
-#define RegisterDEBUGImage  PrependMagickMethod(RegisterDEBUGImage)
-#define RegisterDIBImage  PrependMagickMethod(RegisterDIBImage)
-#define RegisterDJVUImage  PrependMagickMethod(RegisterDJVUImage)
-#define RegisterDNGImage  PrependMagickMethod(RegisterDNGImage)
-#define RegisterDOTImage  PrependMagickMethod(RegisterDOTImage)
-#define RegisterDPXImage  PrependMagickMethod(RegisterDPXImage)
-#define RegisterEPTImage  PrependMagickMethod(RegisterEPTImage)
-#define RegisterEXRImage  PrependMagickMethod(RegisterEXRImage)
-#define RegisterFAXImage  PrependMagickMethod(RegisterFAXImage)
-#define RegisterFDImage  PrependMagickMethod(RegisterFDImage)
-#define RegisterFITSImage  PrependMagickMethod(RegisterFITSImage)
-#define RegisterGIFImage  PrependMagickMethod(RegisterGIFImage)
-#define RegisterGRADIENTImage  PrependMagickMethod(RegisterGRADIENTImage)
-#define RegisterGRAYImage  PrependMagickMethod(RegisterGRAYImage)
-#define RegisterHALDImage  PrependMagickMethod(RegisterHALDImage)
-#define RegisterHDRImage  PrependMagickMethod(RegisterHDRImage)
-#define RegisterHISTOGRAMImage  PrependMagickMethod(RegisterHISTOGRAMImage)
-#define RegisterHRZImage  PrependMagickMethod(RegisterHRZImage)
-#define RegisterHTMLImage  PrependMagickMethod(RegisterHTMLImage)
-#define RegisterICONImage  PrependMagickMethod(RegisterICONImage)
-#define RegisterINFOImage  PrependMagickMethod(RegisterINFOImage)
-#define RegisterINLINEImage  PrependMagickMethod(RegisterINLINEImage)
-#define RegisterIPLImage  PrependMagickMethod(RegisterIPLImage)
-#define RegisterJBIGImage  PrependMagickMethod(RegisterJBIGImage)
-#define RegisterJNXImage  PrependMagickMethod(RegisterJNXImage)
-#define RegisterJP2Image  PrependMagickMethod(RegisterJP2Image)
-#define RegisterJPEGImage  PrependMagickMethod(RegisterJPEGImage)
-#define RegisterJSONImage  PrependMagickMethod(RegisterJSONImage)
-#define RegisterLABELImage  PrependMagickMethod(RegisterLABELImage)
-#define RegisterMACImage  PrependMagickMethod(RegisterMACImage)
-#define RegisterMAPImage  PrependMagickMethod(RegisterMAPImage)
-#define RegisterMASKImage  PrependMagickMethod(RegisterMASKImage)
-#define RegisterMATImage  PrependMagickMethod(RegisterMATImage)
-#define RegisterMATTEImage  PrependMagickMethod(RegisterMATTEImage)
-#define RegisterMETAImage  PrependMagickMethod(RegisterMETAImage)
-#define RegisterMIFFImage  PrependMagickMethod(RegisterMIFFImage)
-#define RegisterMONOImage  PrependMagickMethod(RegisterMONOImage)
-#define RegisterMPCImage  PrependMagickMethod(RegisterMPCImage)
-#define RegisterMPEGImage  PrependMagickMethod(RegisterMPEGImage)
-#define RegisterMPRImage  PrependMagickMethod(RegisterMPRImage)
-#define RegisterMSLImage  PrependMagickMethod(RegisterMSLImage)
-#define RegisterMTVImage  PrependMagickMethod(RegisterMTVImage)
-#define RegisterMVGImage  PrependMagickMethod(RegisterMVGImage)
-#define RegisterNULLImage  PrependMagickMethod(RegisterNULLImage)
-#define RegisterOTBImage  PrependMagickMethod(RegisterOTBImage)
-#define RegisterPALMImage  PrependMagickMethod(RegisterPALMImage)
-#define RegisterPANGOImage  PrependMagickMethod(RegisterPANGOImage)
-#define RegisterPATTERNImage  PrependMagickMethod(RegisterPATTERNImage)
-#define RegisterPCDImage  PrependMagickMethod(RegisterPCDImage)
-#define RegisterPCLImage  PrependMagickMethod(RegisterPCLImage)
-#define RegisterPCXImage  PrependMagickMethod(RegisterPCXImage)
-#define RegisterPDBImage  PrependMagickMethod(RegisterPDBImage)
-#define RegisterPDFImage  PrependMagickMethod(RegisterPDFImage)
-#define RegisterPESImage  PrependMagickMethod(RegisterPESImage)
-#define RegisterPGXImage  PrependMagickMethod(RegisterPGXImage)
-#define RegisterPICTImage  PrependMagickMethod(RegisterPICTImage)
-#define RegisterPIXImage  PrependMagickMethod(RegisterPIXImage)
-#define RegisterPLASMAImage  PrependMagickMethod(RegisterPLASMAImage)
-#define RegisterPNGImage  PrependMagickMethod(RegisterPNGImage)
-#define RegisterPNMImage  PrependMagickMethod(RegisterPNMImage)
-#define RegisterPS2Image  PrependMagickMethod(RegisterPS2Image)
-#define RegisterPS3Image  PrependMagickMethod(RegisterPS3Image)
-#define RegisterPSDImage  PrependMagickMethod(RegisterPSDImage)
-#define RegisterPSImage  PrependMagickMethod(RegisterPSImage)
-#define RegisterPWPImage  PrependMagickMethod(RegisterPWPImage)
-#define RegisterRAWImage  PrependMagickMethod(RegisterRAWImage)
-#define RegisterRGBImage  PrependMagickMethod(RegisterRGBImage)
-#define RegisterRGFImage  PrependMagickMethod(RegisterRGFImage)
-#define RegisterRLAImage  PrependMagickMethod(RegisterRLAImage)
-#define RegisterRLEImage  PrependMagickMethod(RegisterRLEImage)
-#define RegisterSCREENSHOTImage  PrependMagickMethod(RegisterSCREENSHOTImage)
-#define RegisterSCRImage  PrependMagickMethod(RegisterSCRImage)
-#define RegisterSCTImage  PrependMagickMethod(RegisterSCTImage)
-#define RegisterSFWImage  PrependMagickMethod(RegisterSFWImage)
-#define RegisterSGIImage  PrependMagickMethod(RegisterSGIImage)
-#define RegisterSIXELImage  PrependMagickMethod(RegisterSIXELImage)
-#define RegisterStaticModules  PrependMagickMethod(RegisterStaticModules)
-#define RegisterSTEGANOImage  PrependMagickMethod(RegisterSTEGANOImage)
-#define RegisterSUNImage  PrependMagickMethod(RegisterSUNImage)
-#define RegisterSVGImage  PrependMagickMethod(RegisterSVGImage)
-#define RegisterTGAImage  PrependMagickMethod(RegisterTGAImage)
-#define RegisterTHUMBNAILImage  PrependMagickMethod(RegisterTHUMBNAILImage)
-#define RegisterTIFFImage  PrependMagickMethod(RegisterTIFFImage)
-#define RegisterTILEImage  PrependMagickMethod(RegisterTILEImage)
-#define RegisterTIMImage  PrependMagickMethod(RegisterTIMImage)
-#define RegisterTTFImage  PrependMagickMethod(RegisterTTFImage)
-#define RegisterTXTImage  PrependMagickMethod(RegisterTXTImage)
-#define RegisterUILImage  PrependMagickMethod(RegisterUILImage)
-#define RegisterURLImage  PrependMagickMethod(RegisterURLImage)
-#define RegisterUYVYImage  PrependMagickMethod(RegisterUYVYImage)
-#define RegisterVICARImage  PrependMagickMethod(RegisterVICARImage)
-#define RegisterVIDImage  PrependMagickMethod(RegisterVIDImage)
-#define RegisterVIFFImage  PrependMagickMethod(RegisterVIFFImage)
-#define RegisterVIPSImage  PrependMagickMethod(RegisterVIPSImage)
-#define RegisterWBMPImage  PrependMagickMethod(RegisterWBMPImage)
-#define RegisterWEBPImage  PrependMagickMethod(RegisterWEBPImage)
-#define RegisterWMFImage  PrependMagickMethod(RegisterWMFImage)
-#define RegisterWPGImage  PrependMagickMethod(RegisterWPGImage)
-#define RegisterXBMImage  PrependMagickMethod(RegisterXBMImage)
-#define RegisterXCFImage  PrependMagickMethod(RegisterXCFImage)
-#define RegisterXCImage  PrependMagickMethod(RegisterXCImage)
-#define RegisterXImage  PrependMagickMethod(RegisterXImage)
-#define RegisterXPMImage  PrependMagickMethod(RegisterXPMImage)
-#define RegisterXPSImage  PrependMagickMethod(RegisterXPSImage)
-#define RegisterXTRNImage  PrependMagickMethod(RegisterXTRNImage)
-#define RegisterXWDImage  PrependMagickMethod(RegisterXWDImage)
-#define RegisterYCBCRImage  PrependMagickMethod(RegisterYCBCRImage)
-#define RegisterYUVImage  PrependMagickMethod(RegisterYUVImage)
 #define RegistryComponentGenesis  PrependMagickMethod(RegistryComponentGenesis)
 #define RegistryComponentTerminus  PrependMagickMethod(RegistryComponentTerminus)
 #define RelinquishAlignedMemory  PrependMagickMethod(RelinquishAlignedMemory)
@@ -942,6 +820,7 @@ extern "C" {
 #define ReplaceImageInListReturnLast  PrependMagickMethod(ReplaceImageInListReturnLast)
 #define ResampleImage  PrependMagickMethod(ResampleImage)
 #define ResamplePixelColor  PrependMagickMethod(ResamplePixelColor)
+#define ResetCacheAnonymousMemory  PrependMagickMethod(ResetCacheAnonymousMemory)
 #define ResetImageArtifactIterator  PrependMagickMethod(ResetImageArtifactIterator)
 #define ResetImageOptionIterator  PrependMagickMethod(ResetImageOptionIterator)
 #define ResetImageOptions  PrependMagickMethod(ResetImageOptions)
@@ -950,13 +829,16 @@ extern "C" {
 #define ResetImagePropertyIterator  PrependMagickMethod(ResetImagePropertyIterator)
 #define ResetImageRegistryIterator  PrependMagickMethod(ResetImageRegistryIterator)
 #define ResetLinkedListIterator  PrependMagickMethod(ResetLinkedListIterator)
+#define ResetMaxMemoryRequest  PrependMagickMethod(ResetMaxMemoryRequest)
 #define ResetPixelCacheChannels  PrependMagickMethod(ResetPixelCacheChannels)
 #define ResetPixelCacheEpoch  PrependMagickMethod(ResetPixelCacheEpoch)
 #define ResetQuantumState  PrependMagickMethod(ResetQuantumState)
 #define ResetSplayTreeIterator  PrependMagickMethod(ResetSplayTreeIterator)
 #define ResetSplayTree  PrependMagickMethod(ResetSplayTree)
+#define ResetStreamAnonymousMemory  PrependMagickMethod(ResetStreamAnonymousMemory)
 #define ResetStringInfo  PrependMagickMethod(ResetStringInfo)
 #define ResetTimer  PrependMagickMethod(ResetTimer)
+#define ResetVirtualAnonymousMemory  PrependMagickMethod(ResetVirtualAnonymousMemory)
 #define ResizeImage  PrependMagickMethod(ResizeImage)
 #define ResizeQuantumMemory  PrependMagickMethod(ResizeQuantumMemory)
 #define ResourceComponentGenesis  PrependMagickMethod(ResourceComponentGenesis)
@@ -1132,129 +1014,6 @@ extern "C" {
 #define UnityAddKernelInfo  PrependMagickMethod(UnityAddKernelInfo)
 #define UnlockSemaphoreInfo  PrependMagickMethod(UnlockSemaphoreInfo)
 #define UnmapBlob  PrependMagickMethod(UnmapBlob)
-#define UnregisterAAIImage  PrependMagickMethod(UnregisterAAIImage)
-#define UnregisterARTImage  PrependMagickMethod(UnregisterARTImage)
-#define UnregisterAVSImage  PrependMagickMethod(UnregisterAVSImage)
-#define UnregisterBGRImage  PrependMagickMethod(UnregisterBGRImage)
-#define UnregisterBMPImage  PrependMagickMethod(UnregisterBMPImage)
-#define UnregisterBRAILLEImage  PrependMagickMethod(UnregisterBRAILLEImage)
-#define UnregisterCALSImage  PrependMagickMethod(UnregisterCALSImage)
-#define UnregisterCAPTIONImage  PrependMagickMethod(UnregisterCAPTIONImage)
-#define UnregisterCINImage  PrependMagickMethod(UnregisterCINImage)
-#define UnregisterCIPImage  PrependMagickMethod(UnregisterCIPImage)
-#define UnregisterCLIPImage  PrependMagickMethod(UnregisterCLIPImage)
-#define UnregisterCMYKImage  PrependMagickMethod(UnregisterCMYKImage)
-#define UnregisterCUTImage  PrependMagickMethod(UnregisterCUTImage)
-#define UnregisterDCMImage  PrependMagickMethod(UnregisterDCMImage)
-#define UnregisterDDSImage  PrependMagickMethod(UnregisterDDSImage)
-#define UnregisterDEBUGImage  PrependMagickMethod(UnregisterDEBUGImage)
-#define UnregisterDIBImage  PrependMagickMethod(UnregisterDIBImage)
-#define UnregisterDJVUImage  PrependMagickMethod(UnregisterDJVUImage)
-#define UnregisterDNGImage  PrependMagickMethod(UnregisterDNGImage)
-#define UnregisterDOTImage  PrependMagickMethod(UnregisterDOTImage)
-#define UnregisterDPXImage  PrependMagickMethod(UnregisterDPXImage)
-#define UnregisterEPTImage  PrependMagickMethod(UnregisterEPTImage)
-#define UnregisterEXRImage  PrependMagickMethod(UnregisterEXRImage)
-#define UnregisterFAXImage  PrependMagickMethod(UnregisterFAXImage)
-#define UnregisterFDImage  PrependMagickMethod(UnregisterFDImage)
-#define UnregisterFITSImage  PrependMagickMethod(UnregisterFITSImage)
-#define UnregisterGIFImage  PrependMagickMethod(UnregisterGIFImage)
-#define UnregisterGRADIENTImage  PrependMagickMethod(UnregisterGRADIENTImage)
-#define UnregisterGRAYImage  PrependMagickMethod(UnregisterGRAYImage)
-#define UnregisterHALDImage  PrependMagickMethod(UnregisterHALDImage)
-#define UnregisterHDRImage  PrependMagickMethod(UnregisterHDRImage)
-#define UnregisterHISTOGRAMImage  PrependMagickMethod(UnregisterHISTOGRAMImage)
-#define UnregisterHRZImage  PrependMagickMethod(UnregisterHRZImage)
-#define UnregisterHTMLImage  PrependMagickMethod(UnregisterHTMLImage)
-#define UnregisterICONImage  PrependMagickMethod(UnregisterICONImage)
-#define UnregisterINFOImage  PrependMagickMethod(UnregisterINFOImage)
-#define UnregisterINLINEImage  PrependMagickMethod(UnregisterINLINEImage)
-#define UnregisterIPLImage  PrependMagickMethod(UnregisterIPLImage)
-#define UnregisterJBIGImage  PrependMagickMethod(UnregisterJBIGImage)
-#define UnregisterJNXImage  PrependMagickMethod(UnregisterJNXImage)
-#define UnregisterJP2Image  PrependMagickMethod(UnregisterJP2Image)
-#define UnregisterJPEGImage  PrependMagickMethod(UnregisterJPEGImage)
-#define UnregisterJSONImage  PrependMagickMethod(UnregisterJSONImage)
-#define UnregisterLABELImage  PrependMagickMethod(UnregisterLABELImage)
-#define UnregisterMACImage  PrependMagickMethod(UnregisterMACImage)
-#define UnregisterMAPImage  PrependMagickMethod(UnregisterMAPImage)
-#define UnregisterMASKImage  PrependMagickMethod(UnregisterMASKImage)
-#define UnregisterMATImage  PrependMagickMethod(UnregisterMATImage)
-#define UnregisterMATTEImage  PrependMagickMethod(UnregisterMATTEImage)
-#define UnregisterMETAImage  PrependMagickMethod(UnregisterMETAImage)
-#define UnregisterMIFFImage  PrependMagickMethod(UnregisterMIFFImage)
-#define UnregisterMONOImage  PrependMagickMethod(UnregisterMONOImage)
-#define UnregisterMPCImage  PrependMagickMethod(UnregisterMPCImage)
-#define UnregisterMPEGImage  PrependMagickMethod(UnregisterMPEGImage)
-#define UnregisterMPRImage  PrependMagickMethod(UnregisterMPRImage)
-#define UnregisterMSLImage  PrependMagickMethod(UnregisterMSLImage)
-#define UnregisterMTVImage  PrependMagickMethod(UnregisterMTVImage)
-#define UnregisterMVGImage  PrependMagickMethod(UnregisterMVGImage)
-#define UnregisterNULLImage  PrependMagickMethod(UnregisterNULLImage)
-#define UnregisterOTBImage  PrependMagickMethod(UnregisterOTBImage)
-#define UnregisterPALMImage  PrependMagickMethod(UnregisterPALMImage)
-#define UnregisterPANGOImage  PrependMagickMethod(UnregisterPANGOImage)
-#define UnregisterPATTERNImage  PrependMagickMethod(UnregisterPATTERNImage)
-#define UnregisterPCDImage  PrependMagickMethod(UnregisterPCDImage)
-#define UnregisterPCLImage  PrependMagickMethod(UnregisterPCLImage)
-#define UnregisterPCXImage  PrependMagickMethod(UnregisterPCXImage)
-#define UnregisterPDBImage  PrependMagickMethod(UnregisterPDBImage)
-#define UnregisterPDFImage  PrependMagickMethod(UnregisterPDFImage)
-#define UnregisterPESImage  PrependMagickMethod(UnregisterPESImage)
-#define UnregisterPGXImage  PrependMagickMethod(UnregisterPGXImage)
-#define UnregisterPICTImage  PrependMagickMethod(UnregisterPICTImage)
-#define UnregisterPIXImage  PrependMagickMethod(UnregisterPIXImage)
-#define UnregisterPLASMAImage  PrependMagickMethod(UnregisterPLASMAImage)
-#define UnregisterPNGImage  PrependMagickMethod(UnregisterPNGImage)
-#define UnregisterPNMImage  PrependMagickMethod(UnregisterPNMImage)
-#define UnregisterPS2Image  PrependMagickMethod(UnregisterPS2Image)
-#define UnregisterPS3Image  PrependMagickMethod(UnregisterPS3Image)
-#define UnregisterPSDImage  PrependMagickMethod(UnregisterPSDImage)
-#define UnregisterPSImage  PrependMagickMethod(UnregisterPSImage)
-#define UnregisterPWPImage  PrependMagickMethod(UnregisterPWPImage)
-#define UnregisterRAWImage  PrependMagickMethod(UnregisterRAWImage)
-#define UnregisterRGBImage  PrependMagickMethod(UnregisterRGBImage)
-#define UnregisterRGFImage  PrependMagickMethod(UnregisterRGFImage)
-#define UnregisterRLAImage  PrependMagickMethod(UnregisterRLAImage)
-#define UnregisterRLEImage  PrependMagickMethod(UnregisterRLEImage)
-#define UnregisterSCREENSHOTImage  PrependMagickMethod(UnregisterSCREENSHOTImage)
-#define UnregisterSCRImage  PrependMagickMethod(UnregisterSCRImage)
-#define UnregisterSCTImage  PrependMagickMethod(UnregisterSCTImage)
-#define UnregisterSFWImage  PrependMagickMethod(UnregisterSFWImage)
-#define UnregisterSGIImage  PrependMagickMethod(UnregisterSGIImage)
-#define UnregisterSIXELImage  PrependMagickMethod(UnregisterSIXELImage)
-#define UnregisterStaticModules  PrependMagickMethod(UnregisterStaticModules)
-#define UnregisterSTEGANOImage  PrependMagickMethod(UnregisterSTEGANOImage)
-#define UnregisterSUNImage  PrependMagickMethod(UnregisterSUNImage)
-#define UnregisterSVGImage  PrependMagickMethod(UnregisterSVGImage)
-#define UnregisterTGAImage  PrependMagickMethod(UnregisterTGAImage)
-#define UnregisterTHUMBNAILImage  PrependMagickMethod(UnregisterTHUMBNAILImage)
-#define UnregisterTIFFImage  PrependMagickMethod(UnregisterTIFFImage)
-#define UnregisterTILEImage  PrependMagickMethod(UnregisterTILEImage)
-#define UnregisterTIMImage  PrependMagickMethod(UnregisterTIMImage)
-#define UnregisterTTFImage  PrependMagickMethod(UnregisterTTFImage)
-#define UnregisterTXTImage  PrependMagickMethod(UnregisterTXTImage)
-#define UnregisterUILImage  PrependMagickMethod(UnregisterUILImage)
-#define UnregisterURLImage  PrependMagickMethod(UnregisterURLImage)
-#define UnregisterUYVYImage  PrependMagickMethod(UnregisterUYVYImage)
-#define UnregisterVICARImage  PrependMagickMethod(UnregisterVICARImage)
-#define UnregisterVIDImage  PrependMagickMethod(UnregisterVIDImage)
-#define UnregisterVIFFImage  PrependMagickMethod(UnregisterVIFFImage)
-#define UnregisterVIPSImage  PrependMagickMethod(UnregisterVIPSImage)
-#define UnregisterWBMPImage  PrependMagickMethod(UnregisterWBMPImage)
-#define UnregisterWEBPImage  PrependMagickMethod(UnregisterWEBPImage)
-#define UnregisterWMFImage  PrependMagickMethod(UnregisterWMFImage)
-#define UnregisterWPGImage  PrependMagickMethod(UnregisterWPGImage)
-#define UnregisterXBMImage  PrependMagickMethod(UnregisterXBMImage)
-#define UnregisterXCFImage  PrependMagickMethod(UnregisterXCFImage)
-#define UnregisterXCImage  PrependMagickMethod(UnregisterXCImage)
-#define UnregisterXImage  PrependMagickMethod(UnregisterXImage)
-#define UnregisterXPMImage  PrependMagickMethod(UnregisterXPMImage)
-#define UnregisterXPSImage  PrependMagickMethod(UnregisterXPSImage)
-#define UnregisterXTRNImage  PrependMagickMethod(UnregisterXTRNImage)
-#define UnregisterXWDImage  PrependMagickMethod(UnregisterXWDImage)
-#define UnregisterYCBCRImage  PrependMagickMethod(UnregisterYCBCRImage)
-#define UnregisterYUVImage  PrependMagickMethod(UnregisterYUVImage)
 #define UnsharpMaskImage  PrependMagickMethod(UnsharpMaskImage)
 #define UpdateImageViewIterator  PrependMagickMethod(UpdateImageViewIterator)
 #define UpdateSignature  PrependMagickMethod(UpdateSignature)
