@@ -5,7 +5,7 @@
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
 
-    https://www.imagemagick.org/script/license.php
+    https://imagemagick.org/script/license.php
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -139,6 +139,14 @@ static inline size_t GetPixelChannels(const Image *magick_restrict image)
   return(image->number_channels);
 }
 
+static inline Quantum GetPixelCompositeMask(const Image *magick_restrict image,
+  const Quantum *magick_restrict pixel)
+{
+  if (image->channel_map[CompositeMaskPixelChannel].traits == UndefinedPixelTrait)
+    return((Quantum) QuantumRange);
+  return(pixel[image->channel_map[CompositeMaskPixelChannel].offset]);
+}
+
 static inline Quantum GetPixelCr(const Image *magick_restrict image,
   const Quantum *magick_restrict pixel)
 {
@@ -391,27 +399,27 @@ static inline void GetPixelInfoPixel(const Image *magick_restrict image,
       pixel_info->fuzz=image->fuzz;
       pixel_info->depth=image->depth;
       pixel_info->alpha_trait=image->alpha_trait;
-    }
-  if (pixel != (Quantum *) NULL)
-    {
-      pixel_info->red=(MagickRealType)
-        pixel[image->channel_map[RedPixelChannel].offset];
-      pixel_info->green=(MagickRealType)
-        pixel[image->channel_map[GreenPixelChannel].offset];
-      pixel_info->blue=(MagickRealType)
-        pixel[image->channel_map[BluePixelChannel].offset];
-      if (image->channel_map[BlackPixelChannel].traits != UndefinedPixelTrait)
-        pixel_info->black=(MagickRealType)
-          pixel[image->channel_map[BlackPixelChannel].offset];
-      if (image->channel_map[AlphaPixelChannel].traits != UndefinedPixelTrait)
+      if (pixel != (Quantum *) NULL)
         {
-          pixel_info->alpha=(MagickRealType)
-            pixel[image->channel_map[AlphaPixelChannel].offset];
-          pixel_info->alpha_trait=BlendPixelTrait;
+          pixel_info->red=(MagickRealType)
+            pixel[image->channel_map[RedPixelChannel].offset];
+          pixel_info->green=(MagickRealType)
+            pixel[image->channel_map[GreenPixelChannel].offset];
+          pixel_info->blue=(MagickRealType)
+            pixel[image->channel_map[BluePixelChannel].offset];
+          if (image->channel_map[BlackPixelChannel].traits != UndefinedPixelTrait)
+            pixel_info->black=(MagickRealType)
+              pixel[image->channel_map[BlackPixelChannel].offset];
+          if (image->channel_map[AlphaPixelChannel].traits != UndefinedPixelTrait)
+            {
+              pixel_info->alpha=(MagickRealType)
+                pixel[image->channel_map[AlphaPixelChannel].offset];
+              pixel_info->alpha_trait=BlendPixelTrait;
+            }
+          if (image->channel_map[IndexPixelChannel].traits != UndefinedPixelTrait)
+            pixel_info->index=(MagickRealType)
+          pixel[image->channel_map[IndexPixelChannel].offset];
         }
-      if (image->channel_map[IndexPixelChannel].traits != UndefinedPixelTrait)
-        pixel_info->index=(MagickRealType)
-      pixel[image->channel_map[IndexPixelChannel].offset];
     }
 }
 
@@ -629,7 +637,7 @@ static inline void SetPixelb(const Image *magick_restrict image,
 static inline void SetPixelBackgoundColor(const Image *magick_restrict image,
   Quantum *magick_restrict pixel)
 {
-  register ssize_t
+  ssize_t
     i;
 
   for (i=0; i < (ssize_t) GetPixelChannels(image); i++)
@@ -720,6 +728,13 @@ static inline void SetPixelChannelTraits(Image *image,
   image->channel_map[channel].traits=traits;
 }
 
+static inline void SetPixelCompositeMask(const Image *magick_restrict image,
+  const Quantum mask,Quantum *magick_restrict pixel)
+{
+  if (image->channel_map[CompositeMaskPixelChannel].traits != UndefinedPixelTrait)
+    pixel[image->channel_map[CompositeMaskPixelChannel].offset]=mask;
+}
+
 static inline void SetPixelCr(const Image *magick_restrict image,
   const Quantum cr,Quantum *magick_restrict pixel)
 {
